@@ -5,7 +5,7 @@
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/denote-silo
-;; Version: 0.0.0.1
+;; Version: 0.1.0
 ;; Package-Requires: ((emacs "28.1") (denote "3.1.0"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -41,7 +41,9 @@
   "Make it easier to use Denote across Silos."
   :group 'denote
   :link '(info-link "(denote) Top")
-  :link '(url-link :tag "Homepage" "https://protesilaos.com/emacs/denote"))
+  :link '(info-link "(denote-silo) Top")
+  :link '(url-link :tag "Denote homepage" "https://protesilaos.com/emacs/denote")
+  :link '(url-link :tag "Denote Silo homepage" "https://protesilaos.com/emacs/denote-silo"))
 
 (defcustom denote-silo-directories
   `(,denote-directory)
